<th style="vertical-align: middle;">
    <div class="input-group">
        <input type="checkbox" id="select_all_objects_checkbox" style="margin: auto"
               onclick="toggle_select_all_objects();" arial-label="Checkbox for Selection of All Items"/>
    </div>
</th>